<?php

use Symfony\Component\HttpKernel\Kernel;
use Symfony\Component\Config\Loader\LoaderInterface;
use Symfony\Component\HttpKernel\HttpKernelInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Yaml\Yaml;

class AppKernel extends Kernel
{
    public function registerBundles()
    {

        $bundles = [
            new Symfony\Bundle\FrameworkBundle\FrameworkBundle(),
            new Symfony\Bundle\SecurityBundle\SecurityBundle(),
            new Symfony\Bundle\TwigBundle\TwigBundle(),
            new Symfony\Bundle\MonologBundle\MonologBundle(),
            new Symfony\Bundle\SwiftmailerBundle\SwiftmailerBundle(),
            new Doctrine\Bundle\DoctrineBundle\DoctrineBundle(),
            new Sensio\Bundle\FrameworkExtraBundle\SensioFrameworkExtraBundle(),
            new Symfony\Bundle\AsseticBundle\AsseticBundle(),
            new Doctrine\Bundle\MigrationsBundle\DoctrineMigrationsBundle(),
            new Doctrine\Bundle\FixturesBundle\DoctrineFixturesBundle(),
            new Knp\Bundle\PaginatorBundle\KnpPaginatorBundle(),
            new Stfalcon\Bundle\TinymceBundle\StfalconTinymceBundle(),
            new Dj3c1t\AppBundle\Dj3c1tAppBundle(),
            new Dj3c1t\HttpBundle\Dj3c1tHttpBundle(),
            new Dj3c1t\JQFileUploadBundle\Dj3c1tJQFileUploadBundle(),
            new Dj3c1t\SourceMLBundle\Dj3c1tSourceMLBundle(),
        ];

        if (in_array($this->getEnvironment(), ['dev', 'test'], true)) {
            $bundles[] = new Symfony\Bundle\DebugBundle\DebugBundle();
            $bundles[] = new Symfony\Bundle\WebProfilerBundle\WebProfilerBundle();
            $bundles[] = new Sensio\Bundle\DistributionBundle\SensioDistributionBundle();
            $bundles[] = new Sensio\Bundle\GeneratorBundle\SensioGeneratorBundle();
        }

        return $bundles;
    }

    public function getRootDir()
    {
        return __DIR__;
    }

    public function getCacheDir()
    {
        return dirname(__DIR__).'/var/cache/'.$this->getEnvironment();
    }

    public function getLogDir()
    {
        return dirname(__DIR__).'/var/logs';
    }

    public function registerContainerConfiguration(LoaderInterface $loader)
    {
        $loader->load($this->getRootDir().'/config/config_'.$this->getEnvironment().'.yml');
    }

    public function handle(Request $request, $type = HttpKernelInterface::MASTER_REQUEST, $catch = true) {
        try {
            $webDir = $this->getWebDir();
        }
        catch(\Exception $e) {
            return new Response($e->getMessage());
        }
        $symfony_dir = dirname($this->getRootDir());
        if(
                !is_writable($symfony_dir."/var/cache")
            ||  !is_writable($symfony_dir."/var/logs")
            ||  !is_writable($symfony_dir."/".$webDir)
        ) {
            $content =
                "<p>some files or directories aren't writable</p>"
                ."<ul>";
            if(!is_writable($symfony_dir."/var/cache")) {
                $content .= "<li>var/cache</li>";
            }
            if(!is_writable($symfony_dir."/app/logs")) {
                $content .= "<li>var/logs</li>";
            }
            if(!is_writable($symfony_dir."/".$webDir)) {
                $content .= "<li>".$webDir."</li>";
            }
            $content .= "</ul>";
            return new Response($content);
        }
        return parent::handle($request, $type, $catch);
    }

    public function getWebDir() {
        $parameters_file = $this->getRootDir().'/config/parameters.yml';
        if(!@file_exists($parameters_file)) {
            throw new \Exception("missing parameters.yml");
        }
        if(!($content = @file_get_contents($parameters_file))) {
            throw new \Exception("can't read paramerters.yml");
        }
        try {
            $yaml = Yaml::parse($content);
        }
        catch(\Exception $e) {
            throw new \Exception("invalid paramerters.yml");
        }
        if(!isset($yaml['parameters']['web_dir'])) {
            throw new \Exception("missing paramerter web_dir in parameters.yml");
        }
        return $yaml['parameters']['web_dir'];
    }

}
