<?php

/*

    Script de migration des données d'une installation en
    version 1 de SourceML vers une installation en version 2

    UTILISATION DU SCRIPT :

    1)  Faites un backup général de votre ancienne installation
        de SourceML (les dossiers, les fichiers, ainsi qu'un dump
        SQL de la base de données si votre ancienne installation
        utilise MySql).

    2)  Installez la nouvelle version de SourceML.

        Enlevez de votre site les dossiers et les fichiers de
        l'ancienne installation, à l'exception des dossiers "mw"
        et "content".

        Si vous utilisez MySql, laissez les tables dans la base.

        Puis uploadez la nouvelle version sur votre hébergement,
        de manière à ce que le dossier "web" de la nouvelle
        installation contienne les dossiers "mw" et "content" de
        l'ancienne installation.

        Voir la documentation pour plus de détails sur
        l'installation :

        http://www.sourceml.com/index.php?id=8&e=pages/view/page

    3)  La méthode de cryptage des mots de passe change entre la
        version 1 et la version 2 de SourceML. Lors de l'upgrade,
        les mots de passe des utilisateurs sont regénérés.

        Si vous souhaitez qu'un email automatique soit envoyé aux
        utilisateurs, pour leur communiquer leur nouveau mot de passe,
        éditez le fichier :

        previous.version.pathes.php

    4)  Lancez l'upgrade

        Rendez-vous en ligne de commande dans le dossier "web" de
        votre nouvelle installation et lancez ce script :

        php import.previous.version.php

    5)  lorsque la migration est terminée, effacez les dossier "mw" et
        "content" du dossier "web", ainsi que les tables de l'ancienne base
        si vous utilisiez MySql dans l'ancienne installation.

*/

use Symfony\Component\ClassLoader\ApcClassLoader;
use Symfony\Component\HttpFoundation\Request;

error_reporting(E_ALL ^ E_NOTICE);

if(php_sapi_name() !== 'cli') {
    echo "this script is for command line only\n";
    return;
}

echo "\n";
echo "SourceML data import from version 1 to version 2\n";
echo "\n";

$loader = require_once dirname(__DIR__).'/app/autoload.php';
require_once dirname(__DIR__).'/var/bootstrap.php.cache';
$kernel = new AppKernel('prod', false);
$kernel->loadClassCache();

if(!file_exists($previousVersionPathesFile = "previous.version.pathes.php")) {
    echo "impossible de trouver le fichier previous.version.pathes.php\n";
    exit;
}
require_once $previousVersionPathesFile;

if(!file_exists($mwAppFile = $PATHES["mw_path"]."/mw_app.php")) {
    echo "impossible de trouver l'ancienne installation\n";
    exit;
}
require_once $mwAppFile;

$app = new mw_app($previousVersionPathesFile);
if(
        !$app->init_pathes()
    ||  !$app->init_config()
    ||  !$app->init_env()
) {
    echo "impossible d'initialiser l'application\n";
    exit;
}

$request = Request::create('/import/previous_version', 'GET');
$request->attributes->set("mw_app", $app);
$kernel->handle($request);

echo "\n";
